
# Slot: transcribed from


x is transcribed from y if and only if x is synthesized from template y

URI: [biolink:transcribed_from](https://w3id.org/biolink/vocab/transcribed_from)


## Domain and Range

[Transcript](Transcript.md) &#8594;  <sub>0..\*</sub> [Gene](Gene.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | RO:0002510 |
|  | | SIO:010081 |

